@@ -12,12 +12,18 @@ if TYPE_CHECKING:
     from ..models.get_completed_job_response_200_raw_flow_modules_item_retry import (
         GetCompletedJobResponse200RawFlowModulesItemRetry,
     )
+    from ..models.get_completed_job_response_200_raw_flow_modules_item_skip_if import (
+        GetCompletedJobResponse200RawFlowModulesItemSkipIf,
+    )
     from ..models.get_completed_job_response_200_raw_flow_modules_item_sleep_type_0 import (
         GetCompletedJobResponse200RawFlowModulesItemSleepType0,
     )
     from ..models.get_completed_job_response_200_raw_flow_modules_item_sleep_type_1 import (
         GetCompletedJobResponse200RawFlowModulesItemSleepType1,
     )
+    from ..models.get_completed_job_response_200_raw_flow_modules_item_stop_after_all_iters_if import (
+        GetCompletedJobResponse200RawFlowModulesItemStopAfterAllItersIf,
+    )
     from ..models.get_completed_job_response_200_raw_flow_modules_item_stop_after_if import (
         GetCompletedJobResponse200RawFlowModulesItemStopAfterIf,
     )
@@ -36,6 +42,8 @@ class GetCompletedJobResponse200RawFlowModulesItem:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, GetCompletedJobResponse200RawFlowModulesItemStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, GetCompletedJobResponse200RawFlowModulesItemStopAfterAllItersIf]):
+        skip_if (Union[Unset, GetCompletedJobResponse200RawFlowModulesItemSkipIf]):
         sleep (Union['GetCompletedJobResponse200RawFlowModulesItemSleepType0',
             'GetCompletedJobResponse200RawFlowModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
@@ -52,6 +60,8 @@ class GetCompletedJobResponse200RawFlowModulesItem:
     id: str
     value: Any
     stop_after_if: Union[Unset, "GetCompletedJobResponse200RawFlowModulesItemStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "GetCompletedJobResponse200RawFlowModulesItemStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "GetCompletedJobResponse200RawFlowModulesItemSkipIf"] = UNSET
     sleep: Union[
         "GetCompletedJobResponse200RawFlowModulesItemSleepType0",
         "GetCompletedJobResponse200RawFlowModulesItemSleepType1",
@@ -79,6 +89,14 @@ class GetCompletedJobResponse200RawFlowModulesItem:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -121,6 +139,10 @@ class GetCompletedJobResponse200RawFlowModulesItem:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -152,12 +174,18 @@ class GetCompletedJobResponse200RawFlowModulesItem:
         from ..models.get_completed_job_response_200_raw_flow_modules_item_retry import (
             GetCompletedJobResponse200RawFlowModulesItemRetry,
         )
+        from ..models.get_completed_job_response_200_raw_flow_modules_item_skip_if import (
+            GetCompletedJobResponse200RawFlowModulesItemSkipIf,
+        )
         from ..models.get_completed_job_response_200_raw_flow_modules_item_sleep_type_0 import (
             GetCompletedJobResponse200RawFlowModulesItemSleepType0,
         )
         from ..models.get_completed_job_response_200_raw_flow_modules_item_sleep_type_1 import (
             GetCompletedJobResponse200RawFlowModulesItemSleepType1,
         )
+        from ..models.get_completed_job_response_200_raw_flow_modules_item_stop_after_all_iters_if import (
+            GetCompletedJobResponse200RawFlowModulesItemStopAfterAllItersIf,
+        )
         from ..models.get_completed_job_response_200_raw_flow_modules_item_stop_after_if import (
             GetCompletedJobResponse200RawFlowModulesItemStopAfterIf,
         )
@@ -177,6 +205,22 @@ class GetCompletedJobResponse200RawFlowModulesItem:
         else:
             stop_after_if = GetCompletedJobResponse200RawFlowModulesItemStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, GetCompletedJobResponse200RawFlowModulesItemStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = GetCompletedJobResponse200RawFlowModulesItemStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, GetCompletedJobResponse200RawFlowModulesItemSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = GetCompletedJobResponse200RawFlowModulesItemSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union[
@@ -249,6 +293,8 @@ class GetCompletedJobResponse200RawFlowModulesItem:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
