@@ -14,6 +14,7 @@ if TYPE_CHECKING:
     from ..models.get_job_response_200_type_0_args import GetJobResponse200Type0Args
     from ..models.get_job_response_200_type_0_flow_status import GetJobResponse200Type0FlowStatus
     from ..models.get_job_response_200_type_0_raw_flow import GetJobResponse200Type0RawFlow
+    from ..models.get_job_response_200_type_0_workflow_as_code_status import GetJobResponse200Type0WorkflowAsCodeStatus
 
 
 T = TypeVar("T", bound="GetJobResponse200Type0")
@@ -51,6 +52,7 @@ class GetJobResponse200Type0:
         canceled_reason (Union[Unset, str]):
         schedule_path (Union[Unset, str]):
         flow_status (Union[Unset, GetJobResponse200Type0FlowStatus]):
+        workflow_as_code_status (Union[Unset, GetJobResponse200Type0WorkflowAsCodeStatus]):
         raw_flow (Union[Unset, GetJobResponse200Type0RawFlow]):
         language (Union[Unset, GetJobResponse200Type0Language]):
         mem_peak (Union[Unset, int]):
@@ -90,6 +92,7 @@ class GetJobResponse200Type0:
     canceled_reason: Union[Unset, str] = UNSET
     schedule_path: Union[Unset, str] = UNSET
     flow_status: Union[Unset, "GetJobResponse200Type0FlowStatus"] = UNSET
+    workflow_as_code_status: Union[Unset, "GetJobResponse200Type0WorkflowAsCodeStatus"] = UNSET
     raw_flow: Union[Unset, "GetJobResponse200Type0RawFlow"] = UNSET
     language: Union[Unset, GetJobResponse200Type0Language] = UNSET
     mem_peak: Union[Unset, int] = UNSET
@@ -139,6 +142,10 @@ class GetJobResponse200Type0:
         if not isinstance(self.flow_status, Unset):
             flow_status = self.flow_status.to_dict()
 
+        workflow_as_code_status: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.workflow_as_code_status, Unset):
+            workflow_as_code_status = self.workflow_as_code_status.to_dict()
+
         raw_flow: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.raw_flow, Unset):
             raw_flow = self.raw_flow.to_dict()
@@ -207,6 +214,8 @@ class GetJobResponse200Type0:
             field_dict["schedule_path"] = schedule_path
         if flow_status is not UNSET:
             field_dict["flow_status"] = flow_status
+        if workflow_as_code_status is not UNSET:
+            field_dict["workflow_as_code_status"] = workflow_as_code_status
         if raw_flow is not UNSET:
             field_dict["raw_flow"] = raw_flow
         if language is not UNSET:
@@ -235,6 +244,9 @@ class GetJobResponse200Type0:
         from ..models.get_job_response_200_type_0_args import GetJobResponse200Type0Args
         from ..models.get_job_response_200_type_0_flow_status import GetJobResponse200Type0FlowStatus
         from ..models.get_job_response_200_type_0_raw_flow import GetJobResponse200Type0RawFlow
+        from ..models.get_job_response_200_type_0_workflow_as_code_status import (
+            GetJobResponse200Type0WorkflowAsCodeStatus,
+        )
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -301,6 +313,13 @@ class GetJobResponse200Type0:
         else:
             flow_status = GetJobResponse200Type0FlowStatus.from_dict(_flow_status)
 
+        _workflow_as_code_status = d.pop("workflow_as_code_status", UNSET)
+        workflow_as_code_status: Union[Unset, GetJobResponse200Type0WorkflowAsCodeStatus]
+        if isinstance(_workflow_as_code_status, Unset):
+            workflow_as_code_status = UNSET
+        else:
+            workflow_as_code_status = GetJobResponse200Type0WorkflowAsCodeStatus.from_dict(_workflow_as_code_status)
+
         _raw_flow = d.pop("raw_flow", UNSET)
         raw_flow: Union[Unset, GetJobResponse200Type0RawFlow]
         if isinstance(_raw_flow, Unset):
@@ -364,6 +383,7 @@ class GetJobResponse200Type0:
             canceled_reason=canceled_reason,
             schedule_path=schedule_path,
             flow_status=flow_status,
+            workflow_as_code_status=workflow_as_code_status,
             raw_flow=raw_flow,
             language=language,
             mem_peak=mem_peak,
