@@ -14,6 +14,7 @@ if TYPE_CHECKING:
     from ..models.get_job_response_200_type_1_args import GetJobResponse200Type1Args
     from ..models.get_job_response_200_type_1_flow_status import GetJobResponse200Type1FlowStatus
     from ..models.get_job_response_200_type_1_raw_flow import GetJobResponse200Type1RawFlow
+    from ..models.get_job_response_200_type_1_workflow_as_code_status import GetJobResponse200Type1WorkflowAsCodeStatus
 
 
 T = TypeVar("T", bound="GetJobResponse200Type1")
@@ -49,6 +50,7 @@ class GetJobResponse200Type1:
         last_ping (Union[Unset, datetime.datetime]):
         schedule_path (Union[Unset, str]):
         flow_status (Union[Unset, GetJobResponse200Type1FlowStatus]):
+        workflow_as_code_status (Union[Unset, GetJobResponse200Type1WorkflowAsCodeStatus]):
         raw_flow (Union[Unset, GetJobResponse200Type1RawFlow]):
         language (Union[Unset, GetJobResponse200Type1Language]):
         mem_peak (Union[Unset, int]):
@@ -86,6 +88,7 @@ class GetJobResponse200Type1:
     last_ping: Union[Unset, datetime.datetime] = UNSET
     schedule_path: Union[Unset, str] = UNSET
     flow_status: Union[Unset, "GetJobResponse200Type1FlowStatus"] = UNSET
+    workflow_as_code_status: Union[Unset, "GetJobResponse200Type1WorkflowAsCodeStatus"] = UNSET
     raw_flow: Union[Unset, "GetJobResponse200Type1RawFlow"] = UNSET
     language: Union[Unset, GetJobResponse200Type1Language] = UNSET
     mem_peak: Union[Unset, int] = UNSET
@@ -143,6 +146,10 @@ class GetJobResponse200Type1:
         if not isinstance(self.flow_status, Unset):
             flow_status = self.flow_status.to_dict()
 
+        workflow_as_code_status: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.workflow_as_code_status, Unset):
+            workflow_as_code_status = self.workflow_as_code_status.to_dict()
+
         raw_flow: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.raw_flow, Unset):
             raw_flow = self.raw_flow.to_dict()
@@ -209,6 +216,8 @@ class GetJobResponse200Type1:
             field_dict["schedule_path"] = schedule_path
         if flow_status is not UNSET:
             field_dict["flow_status"] = flow_status
+        if workflow_as_code_status is not UNSET:
+            field_dict["workflow_as_code_status"] = workflow_as_code_status
         if raw_flow is not UNSET:
             field_dict["raw_flow"] = raw_flow
         if language is not UNSET:
@@ -237,6 +246,9 @@ class GetJobResponse200Type1:
         from ..models.get_job_response_200_type_1_args import GetJobResponse200Type1Args
         from ..models.get_job_response_200_type_1_flow_status import GetJobResponse200Type1FlowStatus
         from ..models.get_job_response_200_type_1_raw_flow import GetJobResponse200Type1RawFlow
+        from ..models.get_job_response_200_type_1_workflow_as_code_status import (
+            GetJobResponse200Type1WorkflowAsCodeStatus,
+        )
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -319,6 +331,13 @@ class GetJobResponse200Type1:
         else:
             flow_status = GetJobResponse200Type1FlowStatus.from_dict(_flow_status)
 
+        _workflow_as_code_status = d.pop("workflow_as_code_status", UNSET)
+        workflow_as_code_status: Union[Unset, GetJobResponse200Type1WorkflowAsCodeStatus]
+        if isinstance(_workflow_as_code_status, Unset):
+            workflow_as_code_status = UNSET
+        else:
+            workflow_as_code_status = GetJobResponse200Type1WorkflowAsCodeStatus.from_dict(_workflow_as_code_status)
+
         _raw_flow = d.pop("raw_flow", UNSET)
         raw_flow: Union[Unset, GetJobResponse200Type1RawFlow]
         if isinstance(_raw_flow, Unset):
@@ -380,6 +399,7 @@ class GetJobResponse200Type1:
             last_ping=last_ping,
             schedule_path=schedule_path,
             flow_status=flow_status,
+            workflow_as_code_status=workflow_as_code_status,
             raw_flow=raw_flow,
             language=language,
             mem_peak=mem_peak,
