@@ -22,6 +22,9 @@ if TYPE_CHECKING:
     from ..models.get_suspended_job_flow_response_200_job_type_0_raw_flow import (
         GetSuspendedJobFlowResponse200JobType0RawFlow,
     )
+    from ..models.get_suspended_job_flow_response_200_job_type_0_workflow_as_code_status import (
+        GetSuspendedJobFlowResponse200JobType0WorkflowAsCodeStatus,
+    )
 
 
 T = TypeVar("T", bound="GetSuspendedJobFlowResponse200JobType0")
@@ -59,6 +62,7 @@ class GetSuspendedJobFlowResponse200JobType0:
         canceled_reason (Union[Unset, str]):
         schedule_path (Union[Unset, str]):
         flow_status (Union[Unset, GetSuspendedJobFlowResponse200JobType0FlowStatus]):
+        workflow_as_code_status (Union[Unset, GetSuspendedJobFlowResponse200JobType0WorkflowAsCodeStatus]):
         raw_flow (Union[Unset, GetSuspendedJobFlowResponse200JobType0RawFlow]):
         language (Union[Unset, GetSuspendedJobFlowResponse200JobType0Language]):
         mem_peak (Union[Unset, int]):
@@ -98,6 +102,7 @@ class GetSuspendedJobFlowResponse200JobType0:
     canceled_reason: Union[Unset, str] = UNSET
     schedule_path: Union[Unset, str] = UNSET
     flow_status: Union[Unset, "GetSuspendedJobFlowResponse200JobType0FlowStatus"] = UNSET
+    workflow_as_code_status: Union[Unset, "GetSuspendedJobFlowResponse200JobType0WorkflowAsCodeStatus"] = UNSET
     raw_flow: Union[Unset, "GetSuspendedJobFlowResponse200JobType0RawFlow"] = UNSET
     language: Union[Unset, GetSuspendedJobFlowResponse200JobType0Language] = UNSET
     mem_peak: Union[Unset, int] = UNSET
@@ -147,6 +152,10 @@ class GetSuspendedJobFlowResponse200JobType0:
         if not isinstance(self.flow_status, Unset):
             flow_status = self.flow_status.to_dict()
 
+        workflow_as_code_status: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.workflow_as_code_status, Unset):
+            workflow_as_code_status = self.workflow_as_code_status.to_dict()
+
         raw_flow: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.raw_flow, Unset):
             raw_flow = self.raw_flow.to_dict()
@@ -215,6 +224,8 @@ class GetSuspendedJobFlowResponse200JobType0:
             field_dict["schedule_path"] = schedule_path
         if flow_status is not UNSET:
             field_dict["flow_status"] = flow_status
+        if workflow_as_code_status is not UNSET:
+            field_dict["workflow_as_code_status"] = workflow_as_code_status
         if raw_flow is not UNSET:
             field_dict["raw_flow"] = raw_flow
         if language is not UNSET:
@@ -249,6 +260,9 @@ class GetSuspendedJobFlowResponse200JobType0:
         from ..models.get_suspended_job_flow_response_200_job_type_0_raw_flow import (
             GetSuspendedJobFlowResponse200JobType0RawFlow,
         )
+        from ..models.get_suspended_job_flow_response_200_job_type_0_workflow_as_code_status import (
+            GetSuspendedJobFlowResponse200JobType0WorkflowAsCodeStatus,
+        )
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -315,6 +329,15 @@ class GetSuspendedJobFlowResponse200JobType0:
         else:
             flow_status = GetSuspendedJobFlowResponse200JobType0FlowStatus.from_dict(_flow_status)
 
+        _workflow_as_code_status = d.pop("workflow_as_code_status", UNSET)
+        workflow_as_code_status: Union[Unset, GetSuspendedJobFlowResponse200JobType0WorkflowAsCodeStatus]
+        if isinstance(_workflow_as_code_status, Unset):
+            workflow_as_code_status = UNSET
+        else:
+            workflow_as_code_status = GetSuspendedJobFlowResponse200JobType0WorkflowAsCodeStatus.from_dict(
+                _workflow_as_code_status
+            )
+
         _raw_flow = d.pop("raw_flow", UNSET)
         raw_flow: Union[Unset, GetSuspendedJobFlowResponse200JobType0RawFlow]
         if isinstance(_raw_flow, Unset):
@@ -378,6 +401,7 @@ class GetSuspendedJobFlowResponse200JobType0:
             canceled_reason=canceled_reason,
             schedule_path=schedule_path,
             flow_status=flow_status,
+            workflow_as_code_status=workflow_as_code_status,
             raw_flow=raw_flow,
             language=language,
             mem_peak=mem_peak,
