@@ -22,6 +22,9 @@ if TYPE_CHECKING:
     from ..models.get_suspended_job_flow_response_200_job_type_1_raw_flow import (
         GetSuspendedJobFlowResponse200JobType1RawFlow,
     )
+    from ..models.get_suspended_job_flow_response_200_job_type_1_workflow_as_code_status import (
+        GetSuspendedJobFlowResponse200JobType1WorkflowAsCodeStatus,
+    )
 
 
 T = TypeVar("T", bound="GetSuspendedJobFlowResponse200JobType1")
@@ -57,6 +60,7 @@ class GetSuspendedJobFlowResponse200JobType1:
         last_ping (Union[Unset, datetime.datetime]):
         schedule_path (Union[Unset, str]):
         flow_status (Union[Unset, GetSuspendedJobFlowResponse200JobType1FlowStatus]):
+        workflow_as_code_status (Union[Unset, GetSuspendedJobFlowResponse200JobType1WorkflowAsCodeStatus]):
         raw_flow (Union[Unset, GetSuspendedJobFlowResponse200JobType1RawFlow]):
         language (Union[Unset, GetSuspendedJobFlowResponse200JobType1Language]):
         mem_peak (Union[Unset, int]):
@@ -94,6 +98,7 @@ class GetSuspendedJobFlowResponse200JobType1:
     last_ping: Union[Unset, datetime.datetime] = UNSET
     schedule_path: Union[Unset, str] = UNSET
     flow_status: Union[Unset, "GetSuspendedJobFlowResponse200JobType1FlowStatus"] = UNSET
+    workflow_as_code_status: Union[Unset, "GetSuspendedJobFlowResponse200JobType1WorkflowAsCodeStatus"] = UNSET
     raw_flow: Union[Unset, "GetSuspendedJobFlowResponse200JobType1RawFlow"] = UNSET
     language: Union[Unset, GetSuspendedJobFlowResponse200JobType1Language] = UNSET
     mem_peak: Union[Unset, int] = UNSET
@@ -151,6 +156,10 @@ class GetSuspendedJobFlowResponse200JobType1:
         if not isinstance(self.flow_status, Unset):
             flow_status = self.flow_status.to_dict()
 
+        workflow_as_code_status: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.workflow_as_code_status, Unset):
+            workflow_as_code_status = self.workflow_as_code_status.to_dict()
+
         raw_flow: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.raw_flow, Unset):
             raw_flow = self.raw_flow.to_dict()
@@ -217,6 +226,8 @@ class GetSuspendedJobFlowResponse200JobType1:
             field_dict["schedule_path"] = schedule_path
         if flow_status is not UNSET:
             field_dict["flow_status"] = flow_status
+        if workflow_as_code_status is not UNSET:
+            field_dict["workflow_as_code_status"] = workflow_as_code_status
         if raw_flow is not UNSET:
             field_dict["raw_flow"] = raw_flow
         if language is not UNSET:
@@ -251,6 +262,9 @@ class GetSuspendedJobFlowResponse200JobType1:
         from ..models.get_suspended_job_flow_response_200_job_type_1_raw_flow import (
             GetSuspendedJobFlowResponse200JobType1RawFlow,
         )
+        from ..models.get_suspended_job_flow_response_200_job_type_1_workflow_as_code_status import (
+            GetSuspendedJobFlowResponse200JobType1WorkflowAsCodeStatus,
+        )
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -333,6 +347,15 @@ class GetSuspendedJobFlowResponse200JobType1:
         else:
             flow_status = GetSuspendedJobFlowResponse200JobType1FlowStatus.from_dict(_flow_status)
 
+        _workflow_as_code_status = d.pop("workflow_as_code_status", UNSET)
+        workflow_as_code_status: Union[Unset, GetSuspendedJobFlowResponse200JobType1WorkflowAsCodeStatus]
+        if isinstance(_workflow_as_code_status, Unset):
+            workflow_as_code_status = UNSET
+        else:
+            workflow_as_code_status = GetSuspendedJobFlowResponse200JobType1WorkflowAsCodeStatus.from_dict(
+                _workflow_as_code_status
+            )
+
         _raw_flow = d.pop("raw_flow", UNSET)
         raw_flow: Union[Unset, GetSuspendedJobFlowResponse200JobType1RawFlow]
         if isinstance(_raw_flow, Unset):
@@ -394,6 +417,7 @@ class GetSuspendedJobFlowResponse200JobType1:
             last_ping=last_ping,
             schedule_path=schedule_path,
             flow_status=flow_status,
+            workflow_as_code_status=workflow_as_code_status,
             raw_flow=raw_flow,
             language=language,
             mem_peak=mem_peak,
