@@ -10,6 +10,9 @@ if TYPE_CHECKING:
         ListQueueResponse200ItemRawFlowFailureModule,
     )
     from ..models.list_queue_response_200_item_raw_flow_modules_item import ListQueueResponse200ItemRawFlowModulesItem
+    from ..models.list_queue_response_200_item_raw_flow_preprocessor_module import (
+        ListQueueResponse200ItemRawFlowPreprocessorModule,
+    )
 
 
 T = TypeVar("T", bound="ListQueueResponse200ItemRawFlow")
@@ -21,6 +24,7 @@ class ListQueueResponse200ItemRawFlow:
     Attributes:
         modules (List['ListQueueResponse200ItemRawFlowModulesItem']):
         failure_module (Union[Unset, ListQueueResponse200ItemRawFlowFailureModule]):
+        preprocessor_module (Union[Unset, ListQueueResponse200ItemRawFlowPreprocessorModule]):
         same_worker (Union[Unset, bool]):
         concurrent_limit (Union[Unset, float]):
         concurrency_key (Union[Unset, str]):
@@ -33,6 +37,7 @@ class ListQueueResponse200ItemRawFlow:
 
     modules: List["ListQueueResponse200ItemRawFlowModulesItem"]
     failure_module: Union[Unset, "ListQueueResponse200ItemRawFlowFailureModule"] = UNSET
+    preprocessor_module: Union[Unset, "ListQueueResponse200ItemRawFlowPreprocessorModule"] = UNSET
     same_worker: Union[Unset, bool] = UNSET
     concurrent_limit: Union[Unset, float] = UNSET
     concurrency_key: Union[Unset, str] = UNSET
@@ -54,6 +59,10 @@ class ListQueueResponse200ItemRawFlow:
         if not isinstance(self.failure_module, Unset):
             failure_module = self.failure_module.to_dict()
 
+        preprocessor_module: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.preprocessor_module, Unset):
+            preprocessor_module = self.preprocessor_module.to_dict()
+
         same_worker = self.same_worker
         concurrent_limit = self.concurrent_limit
         concurrency_key = self.concurrency_key
@@ -72,6 +81,8 @@ class ListQueueResponse200ItemRawFlow:
         )
         if failure_module is not UNSET:
             field_dict["failure_module"] = failure_module
+        if preprocessor_module is not UNSET:
+            field_dict["preprocessor_module"] = preprocessor_module
         if same_worker is not UNSET:
             field_dict["same_worker"] = same_worker
         if concurrent_limit is not UNSET:
@@ -99,6 +110,9 @@ class ListQueueResponse200ItemRawFlow:
         from ..models.list_queue_response_200_item_raw_flow_modules_item import (
             ListQueueResponse200ItemRawFlowModulesItem,
         )
+        from ..models.list_queue_response_200_item_raw_flow_preprocessor_module import (
+            ListQueueResponse200ItemRawFlowPreprocessorModule,
+        )
 
         d = src_dict.copy()
         modules = []
@@ -115,6 +129,13 @@ class ListQueueResponse200ItemRawFlow:
         else:
             failure_module = ListQueueResponse200ItemRawFlowFailureModule.from_dict(_failure_module)
 
+        _preprocessor_module = d.pop("preprocessor_module", UNSET)
+        preprocessor_module: Union[Unset, ListQueueResponse200ItemRawFlowPreprocessorModule]
+        if isinstance(_preprocessor_module, Unset):
+            preprocessor_module = UNSET
+        else:
+            preprocessor_module = ListQueueResponse200ItemRawFlowPreprocessorModule.from_dict(_preprocessor_module)
+
         same_worker = d.pop("same_worker", UNSET)
 
         concurrent_limit = d.pop("concurrent_limit", UNSET)
@@ -134,6 +155,7 @@ class ListQueueResponse200ItemRawFlow:
         list_queue_response_200_item_raw_flow = cls(
             modules=modules,
             failure_module=failure_module,
+            preprocessor_module=preprocessor_module,
             same_worker=same_worker,
             concurrent_limit=concurrent_limit,
             concurrency_key=concurrency_key,
