@@ -13,6 +13,7 @@ if TYPE_CHECKING:
     from ..models.queued_job_args import QueuedJobArgs
     from ..models.queued_job_flow_status import QueuedJobFlowStatus
     from ..models.queued_job_raw_flow import QueuedJobRawFlow
+    from ..models.queued_job_workflow_as_code_status import QueuedJobWorkflowAsCodeStatus
 
 
 T = TypeVar("T", bound="QueuedJob")
@@ -48,6 +49,7 @@ class QueuedJob:
         last_ping (Union[Unset, datetime.datetime]):
         schedule_path (Union[Unset, str]):
         flow_status (Union[Unset, QueuedJobFlowStatus]):
+        workflow_as_code_status (Union[Unset, QueuedJobWorkflowAsCodeStatus]):
         raw_flow (Union[Unset, QueuedJobRawFlow]):
         language (Union[Unset, QueuedJobLanguage]):
         mem_peak (Union[Unset, int]):
@@ -84,6 +86,7 @@ class QueuedJob:
     last_ping: Union[Unset, datetime.datetime] = UNSET
     schedule_path: Union[Unset, str] = UNSET
     flow_status: Union[Unset, "QueuedJobFlowStatus"] = UNSET
+    workflow_as_code_status: Union[Unset, "QueuedJobWorkflowAsCodeStatus"] = UNSET
     raw_flow: Union[Unset, "QueuedJobRawFlow"] = UNSET
     language: Union[Unset, QueuedJobLanguage] = UNSET
     mem_peak: Union[Unset, int] = UNSET
@@ -140,6 +143,10 @@ class QueuedJob:
         if not isinstance(self.flow_status, Unset):
             flow_status = self.flow_status.to_dict()
 
+        workflow_as_code_status: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.workflow_as_code_status, Unset):
+            workflow_as_code_status = self.workflow_as_code_status.to_dict()
+
         raw_flow: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.raw_flow, Unset):
             raw_flow = self.raw_flow.to_dict()
@@ -203,6 +210,8 @@ class QueuedJob:
             field_dict["schedule_path"] = schedule_path
         if flow_status is not UNSET:
             field_dict["flow_status"] = flow_status
+        if workflow_as_code_status is not UNSET:
+            field_dict["workflow_as_code_status"] = workflow_as_code_status
         if raw_flow is not UNSET:
             field_dict["raw_flow"] = raw_flow
         if language is not UNSET:
@@ -229,6 +238,7 @@ class QueuedJob:
         from ..models.queued_job_args import QueuedJobArgs
         from ..models.queued_job_flow_status import QueuedJobFlowStatus
         from ..models.queued_job_raw_flow import QueuedJobRawFlow
+        from ..models.queued_job_workflow_as_code_status import QueuedJobWorkflowAsCodeStatus
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -311,6 +321,13 @@ class QueuedJob:
         else:
             flow_status = QueuedJobFlowStatus.from_dict(_flow_status)
 
+        _workflow_as_code_status = d.pop("workflow_as_code_status", UNSET)
+        workflow_as_code_status: Union[Unset, QueuedJobWorkflowAsCodeStatus]
+        if isinstance(_workflow_as_code_status, Unset):
+            workflow_as_code_status = UNSET
+        else:
+            workflow_as_code_status = QueuedJobWorkflowAsCodeStatus.from_dict(_workflow_as_code_status)
+
         _raw_flow = d.pop("raw_flow", UNSET)
         raw_flow: Union[Unset, QueuedJobRawFlow]
         if isinstance(_raw_flow, Unset):
@@ -365,6 +382,7 @@ class QueuedJob:
             last_ping=last_ping,
             schedule_path=schedule_path,
             flow_status=flow_status,
+            workflow_as_code_status=workflow_as_code_status,
             raw_flow=raw_flow,
             language=language,
             mem_peak=mem_peak,
