@@ -8,6 +8,7 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.queued_job_raw_flow_failure_module import QueuedJobRawFlowFailureModule
     from ..models.queued_job_raw_flow_modules_item import QueuedJobRawFlowModulesItem
+    from ..models.queued_job_raw_flow_preprocessor_module import QueuedJobRawFlowPreprocessorModule
 
 
 T = TypeVar("T", bound="QueuedJobRawFlow")
@@ -19,6 +20,7 @@ class QueuedJobRawFlow:
     Attributes:
         modules (List['QueuedJobRawFlowModulesItem']):
         failure_module (Union[Unset, QueuedJobRawFlowFailureModule]):
+        preprocessor_module (Union[Unset, QueuedJobRawFlowPreprocessorModule]):
         same_worker (Union[Unset, bool]):
         concurrent_limit (Union[Unset, float]):
         concurrency_key (Union[Unset, str]):
@@ -31,6 +33,7 @@ class QueuedJobRawFlow:
 
     modules: List["QueuedJobRawFlowModulesItem"]
     failure_module: Union[Unset, "QueuedJobRawFlowFailureModule"] = UNSET
+    preprocessor_module: Union[Unset, "QueuedJobRawFlowPreprocessorModule"] = UNSET
     same_worker: Union[Unset, bool] = UNSET
     concurrent_limit: Union[Unset, float] = UNSET
     concurrency_key: Union[Unset, str] = UNSET
@@ -52,6 +55,10 @@ class QueuedJobRawFlow:
         if not isinstance(self.failure_module, Unset):
             failure_module = self.failure_module.to_dict()
 
+        preprocessor_module: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.preprocessor_module, Unset):
+            preprocessor_module = self.preprocessor_module.to_dict()
+
         same_worker = self.same_worker
         concurrent_limit = self.concurrent_limit
         concurrency_key = self.concurrency_key
@@ -70,6 +77,8 @@ class QueuedJobRawFlow:
         )
         if failure_module is not UNSET:
             field_dict["failure_module"] = failure_module
+        if preprocessor_module is not UNSET:
+            field_dict["preprocessor_module"] = preprocessor_module
         if same_worker is not UNSET:
             field_dict["same_worker"] = same_worker
         if concurrent_limit is not UNSET:
@@ -93,6 +102,7 @@ class QueuedJobRawFlow:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.queued_job_raw_flow_failure_module import QueuedJobRawFlowFailureModule
         from ..models.queued_job_raw_flow_modules_item import QueuedJobRawFlowModulesItem
+        from ..models.queued_job_raw_flow_preprocessor_module import QueuedJobRawFlowPreprocessorModule
 
         d = src_dict.copy()
         modules = []
@@ -109,6 +119,13 @@ class QueuedJobRawFlow:
         else:
             failure_module = QueuedJobRawFlowFailureModule.from_dict(_failure_module)
 
+        _preprocessor_module = d.pop("preprocessor_module", UNSET)
+        preprocessor_module: Union[Unset, QueuedJobRawFlowPreprocessorModule]
+        if isinstance(_preprocessor_module, Unset):
+            preprocessor_module = UNSET
+        else:
+            preprocessor_module = QueuedJobRawFlowPreprocessorModule.from_dict(_preprocessor_module)
+
         same_worker = d.pop("same_worker", UNSET)
 
         concurrent_limit = d.pop("concurrent_limit", UNSET)
@@ -128,6 +145,7 @@ class QueuedJobRawFlow:
         queued_job_raw_flow = cls(
             modules=modules,
             failure_module=failure_module,
+            preprocessor_module=preprocessor_module,
             same_worker=same_worker,
             concurrent_limit=concurrent_limit,
             concurrency_key=concurrency_key,
