@@ -8,12 +8,18 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.run_flow_preview_json_body_value_modules_item_mock import RunFlowPreviewJsonBodyValueModulesItemMock
     from ..models.run_flow_preview_json_body_value_modules_item_retry import RunFlowPreviewJsonBodyValueModulesItemRetry
+    from ..models.run_flow_preview_json_body_value_modules_item_skip_if import (
+        RunFlowPreviewJsonBodyValueModulesItemSkipIf,
+    )
     from ..models.run_flow_preview_json_body_value_modules_item_sleep_type_0 import (
         RunFlowPreviewJsonBodyValueModulesItemSleepType0,
     )
     from ..models.run_flow_preview_json_body_value_modules_item_sleep_type_1 import (
         RunFlowPreviewJsonBodyValueModulesItemSleepType1,
     )
+    from ..models.run_flow_preview_json_body_value_modules_item_stop_after_all_iters_if import (
+        RunFlowPreviewJsonBodyValueModulesItemStopAfterAllItersIf,
+    )
     from ..models.run_flow_preview_json_body_value_modules_item_stop_after_if import (
         RunFlowPreviewJsonBodyValueModulesItemStopAfterIf,
     )
@@ -32,6 +38,8 @@ class RunFlowPreviewJsonBodyValueModulesItem:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, RunFlowPreviewJsonBodyValueModulesItemStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, RunFlowPreviewJsonBodyValueModulesItemStopAfterAllItersIf]):
+        skip_if (Union[Unset, RunFlowPreviewJsonBodyValueModulesItemSkipIf]):
         sleep (Union['RunFlowPreviewJsonBodyValueModulesItemSleepType0',
             'RunFlowPreviewJsonBodyValueModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
@@ -48,6 +56,8 @@ class RunFlowPreviewJsonBodyValueModulesItem:
     id: str
     value: Any
     stop_after_if: Union[Unset, "RunFlowPreviewJsonBodyValueModulesItemStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "RunFlowPreviewJsonBodyValueModulesItemStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "RunFlowPreviewJsonBodyValueModulesItemSkipIf"] = UNSET
     sleep: Union[
         "RunFlowPreviewJsonBodyValueModulesItemSleepType0", "RunFlowPreviewJsonBodyValueModulesItemSleepType1", Unset
     ] = UNSET
@@ -73,6 +83,14 @@ class RunFlowPreviewJsonBodyValueModulesItem:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -115,6 +133,10 @@ class RunFlowPreviewJsonBodyValueModulesItem:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -146,12 +168,18 @@ class RunFlowPreviewJsonBodyValueModulesItem:
         from ..models.run_flow_preview_json_body_value_modules_item_retry import (
             RunFlowPreviewJsonBodyValueModulesItemRetry,
         )
+        from ..models.run_flow_preview_json_body_value_modules_item_skip_if import (
+            RunFlowPreviewJsonBodyValueModulesItemSkipIf,
+        )
         from ..models.run_flow_preview_json_body_value_modules_item_sleep_type_0 import (
             RunFlowPreviewJsonBodyValueModulesItemSleepType0,
         )
         from ..models.run_flow_preview_json_body_value_modules_item_sleep_type_1 import (
             RunFlowPreviewJsonBodyValueModulesItemSleepType1,
         )
+        from ..models.run_flow_preview_json_body_value_modules_item_stop_after_all_iters_if import (
+            RunFlowPreviewJsonBodyValueModulesItemStopAfterAllItersIf,
+        )
         from ..models.run_flow_preview_json_body_value_modules_item_stop_after_if import (
             RunFlowPreviewJsonBodyValueModulesItemStopAfterIf,
         )
@@ -171,6 +199,22 @@ class RunFlowPreviewJsonBodyValueModulesItem:
         else:
             stop_after_if = RunFlowPreviewJsonBodyValueModulesItemStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, RunFlowPreviewJsonBodyValueModulesItemStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = RunFlowPreviewJsonBodyValueModulesItemStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, RunFlowPreviewJsonBodyValueModulesItemSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = RunFlowPreviewJsonBodyValueModulesItemSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union[
@@ -243,6 +287,8 @@ class RunFlowPreviewJsonBodyValueModulesItem:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
