@@ -1,7 +1,9 @@
+import datetime
 from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
+from dateutil.parser import isoparse
 
 from ..types import UNSET, Unset
 
@@ -9,6 +11,7 @@ if TYPE_CHECKING:
     from ..models.update_schedule_json_body_args import UpdateScheduleJsonBodyArgs
     from ..models.update_schedule_json_body_on_failure_extra_args import UpdateScheduleJsonBodyOnFailureExtraArgs
     from ..models.update_schedule_json_body_on_recovery_extra_args import UpdateScheduleJsonBodyOnRecoveryExtraArgs
+    from ..models.update_schedule_json_body_on_success_extra_args import UpdateScheduleJsonBodyOnSuccessExtraArgs
     from ..models.update_schedule_json_body_retry import UpdateScheduleJsonBodyRetry
 
 
@@ -29,11 +32,16 @@ class UpdateScheduleJsonBody:
         on_recovery (Union[Unset, str]):
         on_recovery_times (Union[Unset, float]):
         on_recovery_extra_args (Union[Unset, UpdateScheduleJsonBodyOnRecoveryExtraArgs]):
+        on_success (Union[Unset, str]):
+        on_success_extra_args (Union[Unset, UpdateScheduleJsonBodyOnSuccessExtraArgs]):
         ws_error_handler_muted (Union[Unset, bool]):
         retry (Union[Unset, UpdateScheduleJsonBodyRetry]):
         no_flow_overlap (Union[Unset, bool]):
         summary (Union[Unset, str]):
+        description (Union[Unset, str]):
         tag (Union[Unset, str]):
+        paused_until (Union[Unset, datetime.datetime]):
+        cron_version (Union[Unset, str]):
     """
 
     schedule: str
@@ -46,11 +54,16 @@ class UpdateScheduleJsonBody:
     on_recovery: Union[Unset, str] = UNSET
     on_recovery_times: Union[Unset, float] = UNSET
     on_recovery_extra_args: Union[Unset, "UpdateScheduleJsonBodyOnRecoveryExtraArgs"] = UNSET
+    on_success: Union[Unset, str] = UNSET
+    on_success_extra_args: Union[Unset, "UpdateScheduleJsonBodyOnSuccessExtraArgs"] = UNSET
     ws_error_handler_muted: Union[Unset, bool] = UNSET
     retry: Union[Unset, "UpdateScheduleJsonBodyRetry"] = UNSET
     no_flow_overlap: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
+    description: Union[Unset, str] = UNSET
     tag: Union[Unset, str] = UNSET
+    paused_until: Union[Unset, datetime.datetime] = UNSET
+    cron_version: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -71,6 +84,11 @@ class UpdateScheduleJsonBody:
         if not isinstance(self.on_recovery_extra_args, Unset):
             on_recovery_extra_args = self.on_recovery_extra_args.to_dict()
 
+        on_success = self.on_success
+        on_success_extra_args: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.on_success_extra_args, Unset):
+            on_success_extra_args = self.on_success_extra_args.to_dict()
+
         ws_error_handler_muted = self.ws_error_handler_muted
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
@@ -78,7 +96,13 @@ class UpdateScheduleJsonBody:
 
         no_flow_overlap = self.no_flow_overlap
         summary = self.summary
+        description = self.description
         tag = self.tag
+        paused_until: Union[Unset, str] = UNSET
+        if not isinstance(self.paused_until, Unset):
+            paused_until = self.paused_until.isoformat()
+
+        cron_version = self.cron_version
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -103,6 +127,10 @@ class UpdateScheduleJsonBody:
             field_dict["on_recovery_times"] = on_recovery_times
         if on_recovery_extra_args is not UNSET:
             field_dict["on_recovery_extra_args"] = on_recovery_extra_args
+        if on_success is not UNSET:
+            field_dict["on_success"] = on_success
+        if on_success_extra_args is not UNSET:
+            field_dict["on_success_extra_args"] = on_success_extra_args
         if ws_error_handler_muted is not UNSET:
             field_dict["ws_error_handler_muted"] = ws_error_handler_muted
         if retry is not UNSET:
@@ -111,8 +139,14 @@ class UpdateScheduleJsonBody:
             field_dict["no_flow_overlap"] = no_flow_overlap
         if summary is not UNSET:
             field_dict["summary"] = summary
+        if description is not UNSET:
+            field_dict["description"] = description
         if tag is not UNSET:
             field_dict["tag"] = tag
+        if paused_until is not UNSET:
+            field_dict["paused_until"] = paused_until
+        if cron_version is not UNSET:
+            field_dict["cron_version"] = cron_version
 
         return field_dict
 
@@ -121,6 +155,7 @@ class UpdateScheduleJsonBody:
         from ..models.update_schedule_json_body_args import UpdateScheduleJsonBodyArgs
         from ..models.update_schedule_json_body_on_failure_extra_args import UpdateScheduleJsonBodyOnFailureExtraArgs
         from ..models.update_schedule_json_body_on_recovery_extra_args import UpdateScheduleJsonBodyOnRecoveryExtraArgs
+        from ..models.update_schedule_json_body_on_success_extra_args import UpdateScheduleJsonBodyOnSuccessExtraArgs
         from ..models.update_schedule_json_body_retry import UpdateScheduleJsonBodyRetry
 
         d = src_dict.copy()
@@ -154,6 +189,15 @@ class UpdateScheduleJsonBody:
         else:
             on_recovery_extra_args = UpdateScheduleJsonBodyOnRecoveryExtraArgs.from_dict(_on_recovery_extra_args)
 
+        on_success = d.pop("on_success", UNSET)
+
+        _on_success_extra_args = d.pop("on_success_extra_args", UNSET)
+        on_success_extra_args: Union[Unset, UpdateScheduleJsonBodyOnSuccessExtraArgs]
+        if isinstance(_on_success_extra_args, Unset):
+            on_success_extra_args = UNSET
+        else:
+            on_success_extra_args = UpdateScheduleJsonBodyOnSuccessExtraArgs.from_dict(_on_success_extra_args)
+
         ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
 
         _retry = d.pop("retry", UNSET)
@@ -167,8 +211,19 @@ class UpdateScheduleJsonBody:
 
         summary = d.pop("summary", UNSET)
 
+        description = d.pop("description", UNSET)
+
         tag = d.pop("tag", UNSET)
 
+        _paused_until = d.pop("paused_until", UNSET)
+        paused_until: Union[Unset, datetime.datetime]
+        if isinstance(_paused_until, Unset):
+            paused_until = UNSET
+        else:
+            paused_until = isoparse(_paused_until)
+
+        cron_version = d.pop("cron_version", UNSET)
+
         update_schedule_json_body = cls(
             schedule=schedule,
             timezone=timezone,
@@ -180,11 +235,16 @@ class UpdateScheduleJsonBody:
             on_recovery=on_recovery,
             on_recovery_times=on_recovery_times,
             on_recovery_extra_args=on_recovery_extra_args,
+            on_success=on_success,
+            on_success_extra_args=on_success_extra_args,
             ws_error_handler_muted=ws_error_handler_muted,
             retry=retry,
             no_flow_overlap=no_flow_overlap,
             summary=summary,
+            description=description,
             tag=tag,
+            paused_until=paused_until,
+            cron_version=cron_version,
         )
 
         update_schedule_json_body.additional_properties = d
