@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -8,6 +8,12 @@ from ..models.workspace_git_sync_settings_repositories_item_exclude_types_overri
 )
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.workspace_git_sync_settings_repositories_item_settings import (
+        WorkspaceGitSyncSettingsRepositoriesItemSettings,
+    )
+
+
 T = TypeVar("T", bound="WorkspaceGitSyncSettingsRepositoriesItem")
 
 
@@ -19,6 +25,8 @@ class WorkspaceGitSyncSettingsRepositoriesItem:
         git_repo_resource_path (str):
         use_individual_branch (Union[Unset, bool]):
         group_by_folder (Union[Unset, bool]):
+        collapsed (Union[Unset, bool]):
+        settings (Union[Unset, WorkspaceGitSyncSettingsRepositoriesItemSettings]):
         exclude_types_override (Union[Unset, List[WorkspaceGitSyncSettingsRepositoriesItemExcludeTypesOverrideItem]]):
     """
 
@@ -26,6 +34,8 @@ class WorkspaceGitSyncSettingsRepositoriesItem:
     git_repo_resource_path: str
     use_individual_branch: Union[Unset, bool] = UNSET
     group_by_folder: Union[Unset, bool] = UNSET
+    collapsed: Union[Unset, bool] = UNSET
+    settings: Union[Unset, "WorkspaceGitSyncSettingsRepositoriesItemSettings"] = UNSET
     exclude_types_override: Union[Unset, List[WorkspaceGitSyncSettingsRepositoriesItemExcludeTypesOverrideItem]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -34,6 +44,11 @@ class WorkspaceGitSyncSettingsRepositoriesItem:
         git_repo_resource_path = self.git_repo_resource_path
         use_individual_branch = self.use_individual_branch
         group_by_folder = self.group_by_folder
+        collapsed = self.collapsed
+        settings: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.settings, Unset):
+            settings = self.settings.to_dict()
+
         exclude_types_override: Union[Unset, List[str]] = UNSET
         if not isinstance(self.exclude_types_override, Unset):
             exclude_types_override = []
@@ -54,6 +69,10 @@ class WorkspaceGitSyncSettingsRepositoriesItem:
             field_dict["use_individual_branch"] = use_individual_branch
         if group_by_folder is not UNSET:
             field_dict["group_by_folder"] = group_by_folder
+        if collapsed is not UNSET:
+            field_dict["collapsed"] = collapsed
+        if settings is not UNSET:
+            field_dict["settings"] = settings
         if exclude_types_override is not UNSET:
             field_dict["exclude_types_override"] = exclude_types_override
 
@@ -61,6 +80,10 @@ class WorkspaceGitSyncSettingsRepositoriesItem:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.workspace_git_sync_settings_repositories_item_settings import (
+            WorkspaceGitSyncSettingsRepositoriesItemSettings,
+        )
+
         d = src_dict.copy()
         script_path = d.pop("script_path")
 
@@ -70,6 +93,15 @@ class WorkspaceGitSyncSettingsRepositoriesItem:
 
         group_by_folder = d.pop("group_by_folder", UNSET)
 
+        collapsed = d.pop("collapsed", UNSET)
+
+        _settings = d.pop("settings", UNSET)
+        settings: Union[Unset, WorkspaceGitSyncSettingsRepositoriesItemSettings]
+        if isinstance(_settings, Unset):
+            settings = UNSET
+        else:
+            settings = WorkspaceGitSyncSettingsRepositoriesItemSettings.from_dict(_settings)
+
         exclude_types_override = []
         _exclude_types_override = d.pop("exclude_types_override", UNSET)
         for exclude_types_override_item_data in _exclude_types_override or []:
@@ -84,6 +116,8 @@ class WorkspaceGitSyncSettingsRepositoriesItem:
             git_repo_resource_path=git_repo_resource_path,
             use_individual_branch=use_individual_branch,
             group_by_folder=group_by_folder,
+            collapsed=collapsed,
+            settings=settings,
             exclude_types_override=exclude_types_override,
         )
 
